@@ -1,17 +1,18 @@
 """Module to handle dataset-related operations within a project."""
+
 import os
 import sys
-
 import requests
 from matrice.utils import handle_response
 from datetime import datetime, timedelta
 
 
-def get_dataset_size(session, url, project_id):
+def get_dataset_size_in_mb_from_url(session, url, project_id):
     """
     Fetch the size of a dataset from the specified URL.
 
-    This function sends a request to retrieve the dataset size, measured in megabytes, for a given project.
+    This function sends a request to retrieve the dataset size, measured in megabytes,
+    for a given project.
 
     Parameters
     ----------
@@ -32,7 +33,8 @@ def get_dataset_size(session, url, project_id):
 
     Example
     -------
-    >>> size_info, err, msg = get_dataset_size(session=session, url="https://example.com/dataset.zip", project_id="12345")
+    >>> size_info, err, msg = get_dataset_size(session=session,
+    url="https://example.com/dataset.zip", project_id="12345")
     >>> if err:
     >>>     print(f"Error: {err}")
     >>> else:
@@ -41,10 +43,15 @@ def get_dataset_size(session, url, project_id):
     path = f"/v1/dataset/get_dataset_size_in_mb_from_url?projectId={project_id}"
     requested_payload = {"datasetUrl": url}
     headers = {"Content-Type": "application/json"}
-    resp = session.rpc.post(path=path, headers=headers, payload=requested_payload)
-
+    resp = session.rpc.post(
+        path=path,
+        headers=headers,
+        payload=requested_payload,
+    )
     return handle_response(
-        resp, f"Dataset size fetched successfully", "Could not fetch dataset size"
+        resp,
+        "Dataset size fetched successfully",
+        "Could not fetch dataset size",
     )
 
 
@@ -80,13 +87,14 @@ def upload_file(session, file_path):
     """
     file_name = os.path.basename(file_path)
     upload_url, error, message = _get_upload_path(session, file_name)
-
     if error is not None:
-        return {"success": False, "data": "", "message": message}
-
+        return {
+            "success": False,
+            "data": "",
+            "message": message,
+        }
     with open(file_path, "rb") as file:
-        response = requests.put(upload_url, data=file)
-
+        response = requests.put(upload_url, data=file, timeout=30)
     if response.status_code == 200:
         return {
             "success": True,
@@ -133,7 +141,9 @@ def _get_upload_path(session, file_name):
     path = f"/v1/dataset/upload-path?fileName={file_name}"
     resp = session.rpc.get(path=path)
     return handle_response(
-        resp, "Upload Path fetched successfully", "Could not fetch upload path"
+        resp,
+        "Upload Path fetched successfully",
+        "Could not fetch upload path",
     )
 
 
@@ -141,7 +151,7 @@ class Dataset:
     """
     Class to handle dataset-related operations within a project.
 
-    This class manages operations on a dataset within a specified project. During initialization, 
+    This class manages operations on a dataset within a specified project. During initialization,
     either `dataset_name` or `dataset_id` must be provided to locate the dataset.
 
     Parameters
@@ -151,7 +161,8 @@ class Dataset:
     dataset_id : str, optional
         The ID of the dataset (default is None). Used to directly locate the dataset.
     dataset_name : str, optional
-        The name of the dataset (default is None). If `dataset_id` is not provided, `dataset_name` will be used to find the dataset.
+        The name of the dataset (default is None). If `dataset_id` is not provided,
+        `dataset_name` will be used to find the dataset.
 
     Attributes
     ----------
@@ -172,12 +183,14 @@ class Dataset:
     last_updated_at : str
         The timestamp of the dataset's most recent update.
     summary : dict
-        Summary of the dataset's latest version, providing metrics like item count and class distribution.
+        Summary of the dataset's latest version, providing metrics like item count and class
+            distribution.
 
     Raises
     ------
     ValueError
-        If neither `dataset_id` nor `dataset_name` is provided, or if there is a mismatch between `dataset_id` and `dataset_name`.
+        If neither `dataset_id` nor `dataset_name` is provided, or if there is a mismatch between
+            `dataset_id` and `dataset_name`.
 
     Example
     -------
@@ -188,7 +201,12 @@ class Dataset:
     >>> print(f"Latest Version: {dataset.latest_version}")
     """
 
-    def __init__(self, session, dataset_id=None, dataset_name=None):
+    def __init__(
+        self,
+        session,
+        dataset_id=None,
+        dataset_name=None,
+    ):
         self.session = session
         self.project_id = session.project_id
         self.last_refresh_time = datetime.now()
@@ -196,62 +214,48 @@ class Dataset:
         self.dataset_name = dataset_name
         self.rpc = session.rpc
         assert dataset_id or dataset_name, "Either dataset_id or dataset_name must be provided"
-            
-        # Fetch dataset by name only if only dataset_name is provided
         if dataset_name is not None:
             dataset_by_name, err, msg = self._get_dataset_by_name()
             if self.dataset_id is None:
                 if dataset_by_name is None:
                     raise ValueError(f"Dataset with name '{self.dataset_name}' not found.")
-                
-                self.dataset_id = dataset_by_name['_id']
-            
-            # If both dataset_id and dataset_name are provided, check for mismatch
+                self.dataset_id = dataset_by_name["_id"]
             elif self.dataset_id is not None and self.dataset_name is not None:
-                fetched_dataset_id = dataset_by_name['_id']
-                    
+                fetched_dataset_id = dataset_by_name["_id"]
                 if fetched_dataset_id != self.dataset_id:
-                    raise ValueError("Provided dataset_id does not match the dataset id of the provided dataset_name.")
-                
-        
+                    raise ValueError(
+                        "Provided dataset_id does not match the dataset id of the provided dataset_name."
+                    )
         self.dataset_details, error, message = self._get_details()
-        self.dataset_id = self.dataset_details['_id']
-        self.dataset_name = self.dataset_details['name']
+        self.dataset_id = self.dataset_details["_id"]
+        self.dataset_name = self.dataset_details["name"]
         self.version_status = self.dataset_details.get("stats", [{}])[0].get("versionStatus")
-        self.latest_version = self.dataset_details['latestVersion']
-        self.no_of_samples = sum(version['versionStats']['total'] for version in self.dataset_details.get('stats', []))
-        self.no_of_classes = len(self.dataset_details.get('stats', [{}])[0].get('classStat', {}))
-        self.no_of_versions = len(self.dataset_details.get('allVersions', []))
-        self.last_updated_at = self.dataset_details.get('updatedAt')
-        self.summary , err , msg = self._get_summary(self.dataset_details['latestVersion'])
-
+        self.latest_version = self.dataset_details["latestVersion"]
+        self.no_of_samples = sum(
+            version["versionStats"]["total"] for version in self.dataset_details.get("stats", [])
+        )
+        self.no_of_classes = len(self.dataset_details.get("stats", [{}])[0].get("classStat", {}))
+        self.no_of_versions = len(self.dataset_details.get("allVersions", []))
+        self.last_updated_at = self.dataset_details.get("updatedAt")
 
     def refresh(self):
         """
         Refresh the instance by reinstantiating it with the previous values.
         """
-        # Check if two minutes have passed since the last refresh
         if datetime.now() - self.last_refresh_time < timedelta(minutes=2):
             raise Exception("Refresh can only be called after two minutes since the last refresh.")
-
-        # Capture the current state
-        state = self.__dict__.copy()
-
+        self.__dict__.copy()
         init_params = {
-        'session': self.session,
-        'dataset_id': self.dataset_id,
-    }
-
-        # Reinitialize the instance
+            "session": self.session,
+            "dataset_id": self.dataset_id,
+        }
         self.__init__(**init_params)
-        
-
-        # Update the last refresh time
         self.last_refresh_time = datetime.now()
-        
+
     def _get_details(self):
         """
-        Retrieve dataset details based on the dataset ID or dataset name set during class initialization.
+        Retrieve dataset details based on the dataset ID or dataset name set during class
+            initialization.
 
         This method attempts to fetch the dataset details using the dataset ID, if available.
         If the dataset ID is not provided, it will attempt to retrieve details by the dataset name.
@@ -273,12 +277,13 @@ class Dataset:
                     - `datasetDesc` (str): Description of the dataset.
                     - `latestVersion` (str): Identifier of the latest dataset version.
                     - `name` (str): Name of the dataset.
-                    - `stats` (list of dict): Version-specific statistics, including sample counts and splits.
+                    - `stats` (list of dict): Version-specific statistics, including sample counts
+                        and splits.
                     - `type` (str): Type of dataset (e.g., `classification`, `detection`).
                     - `updatedAt` (str): Last update timestamp of the dataset.
-            - str or None: 
+            - str or None:
                 Error message if an error occurred, `None` otherwise.
-            - str: 
+            - str:
                 Status message indicating success or failure.
 
         Raises
@@ -293,7 +298,7 @@ class Dataset:
         >>>     pprint(err)
         >>> else:
         >>>     pprint(dataset_details)
-        >>> 
+        >>>
         >>> # Sample output
         >>> {
         >>>     '_id': '671636dd5cffa65a7510a52b',
@@ -306,11 +311,11 @@ class Dataset:
         Notes
         -----
         - `_get_dataset()` is called if `dataset_id` is set to retrieve the dataset by its ID.
-        - `_get_dataset_by_name()` is used if `dataset_name` is set to fetch the dataset by its name.
+        - `_get_dataset_by_name()` is used if `dataset_name` is set to fetch the dataset by its
+            name.
         """
         id = self.dataset_id
         name = self.dataset_name
-
         if id:
             try:
                 return self._get_dataset()
@@ -322,16 +327,15 @@ class Dataset:
             except Exception as e:
                 print(f"Error retrieving dataset by name: {e}")
         else:
-            raise ValueError(
-                "At least one of 'dataset_id' or 'dataset_name' must be provided."
-            )
+            raise ValueError("At least one of 'dataset_id' or 'dataset_name' must be provided.")
 
     def _get_summary(self, dataset_version):
         """
         Retrieve a summary for a specific dataset version.
 
         This method provides essential metrics for a specified version of the dataset.
-        Only the `dataset_version` is required, as `dataset_id` and `project_id` are already set during initialization.
+        Only the `dataset_version` is required, as `dataset_id` and `project_id` are already set
+            during initialization.
 
         Parameters
         ----------
@@ -345,7 +349,8 @@ class Dataset:
             - dict: Key summary details of the dataset, including:
                 - `categoryCount` (int): The number of unique categories in the dataset.
                 - `dataItemCount` (int): Total number of data items in the dataset.
-                - `histogram` (list of dict): Distribution of items per category, with each dictionary containing:
+                - `histogram` (list of dict): Distribution of items per category,
+                with each dictionary containing:
                     - `_id` (str): Unique identifier for each category.
                     - `count` (int): Total count of items in this category.
                     - `label` (str): Name of the category.
@@ -372,12 +377,13 @@ class Dataset:
         >>>     pprint(err)
         >>> else:
         >>>     pprint(summary)
-        >>> 
+        >>>
         >>> # Sample output
         >>> {
         >>>     'categoryCount': 2,
         >>>     'dataItemCount': 2877,
-        >>>     'histogram': [{'_id': '671638ef0f4507663b8ca2b7', 'count': 81524, 'label': 'Window', 'train': 70643, 'val': 7302, 'test': 3579, 'unassigned': 0}],
+        >>>     'histogram': [{'_id': '671638ef0f4507663b8ca2b7', 'count': 81524, 'label': 'Window',
+        'train': 70643, 'val': 7302, 'test': 3579, 'unassigned': 0}],
         >>>     'testDataItemCount': 120,
         >>>     'trainDataItemCount': 2517,
         >>>     'unassignedDataItemCount': 0,
@@ -389,10 +395,8 @@ class Dataset:
                 "Dataset id not set for this dataset. Cannot perform the operation for dataset without dataset id"
             )
             sys.exit(0)
-
         path = f"/v1/dataset/{self.dataset_id}/version/{dataset_version}/summary?projectId={self.project_id}"
         resp = self.rpc.get(path=path)
-
         return handle_response(
             resp,
             "Dataset summary fetched successfully",
@@ -403,7 +407,8 @@ class Dataset:
         """
         Fetch dataset details using the dataset ID.
 
-        This function retrieves detailed information about the dataset by its ID. The dataset ID must be set during 
+        This function retrieves detailed information about the dataset by its ID. The dataset ID
+            must be set during
         initialization for this function to work.
 
         Returns
@@ -421,7 +426,8 @@ class Dataset:
                 - `datasetDesc` (str): Description of the dataset.
                 - `latestVersion` (str): Identifier of the latest dataset version.
                 - `name` (str): Name of the dataset.
-                - `stats` (list of dict): Version-specific statistics, including sample counts and splits.
+                - `stats` (list of dict): Version-specific statistics, including sample counts and
+                    splits.
                 - `type` (str): Type of dataset (e.g., `classification`, `detection`).
                 - `updatedAt` (str): Last update timestamp of the dataset.
             - str or None: Error message if an error occurred, `None` otherwise.
@@ -439,7 +445,7 @@ class Dataset:
         >>>     pprint(err)
         >>> else:
         >>>     pprint(resp)
-        >>> 
+        >>>
         >>> # Sample output
         >>> {
         >>>     '_id': '671636dd5cffa65a7510a52b',
@@ -454,19 +460,19 @@ class Dataset:
                 "Dataset id not set for this dataset. Cannot perform the operation for dataset without dataset id"
             )
             sys.exit(0)
-
         path = f"/v1/dataset/{self.dataset_id}?projectId={self.project_id}"
         resp = self.rpc.get(path=path)
-
         return handle_response(
-            resp, "Dataset fetched successfully", "Could not fetch dataset"
+            resp,
+            "Dataset fetched successfully",
+            "Could not fetch dataset",
         )
 
     def get_categories(self, dataset_version):
         """
         Get category details for a specific dataset version.
 
-        This function retrieves the categories available in a specified version of the dataset, 
+        This function retrieves the categories available in a specified version of the dataset,
         including category IDs, names, and associated metadata.
 
         Parameters
@@ -499,11 +505,13 @@ class Dataset:
         >>>     pprint(err)
         >>> else:
         >>>     pprint(categories[:3])
-        >>> 
+        >>>
         >>> # Sample output
         >>> [
-        >>>     {'_id': '671638ef0f4507663b8ca2b7', '_idDataset': '671636dd6cffa65a7510a52b', '_idSuperCategory': '000000000000000000000000', 'datasetVersion': 'v1.0', 'name': 'Dog'},
-        >>>     {'_id': '671638ef0f4507663b8ca2b6', '_idDataset': '671636dd6cffa65a7510a52b', '_idSuperCategory': '000000000000000000000000', 'datasetVersion': 'v1.0', 'name': 'Cat'},
+        >>>     {'_id': '671638ef0f4507663b8ca2b7', '_idDataset': '671636dd6cffa65a7510a52b',
+        '_idSuperCategory': '000000000000000000000000', 'datasetVersion': 'v1.0', 'name': 'Dog'},
+        >>>     {'_id': '671638ef0f4507663b8ca2b6', '_idDataset': '671636dd6cffa65a7510a52b',
+        '_idSuperCategory': '000000000000000000000000', 'datasetVersion': 'v1.0', 'name': 'Cat'},
         >>>     ...
         >>> ]
         """
@@ -512,17 +520,20 @@ class Dataset:
                 "Dataset id not set for this dataset. Cannot perform the operation for dataset without dataset id"
             )
             sys.exit(0)
-
         path = f"/v1/dataset/{self.dataset_id}/version/{dataset_version}/categories?projectId={self.project_id}"
         resp = self.rpc.get(path=path)
-
         return handle_response(
             resp,
             f"Dataset categories for version - {dataset_version} fetched successfully",
             "Could not fetch dataset categories",
         )
 
-    def _list_items_V2(self, dataset_version, page_size = 10, page_number = 0):
+    def _list_items_V2(
+        self,
+        dataset_version,
+        page_size=10,
+        page_number=0,
+    ):
         """
         List items for a specific version of the dataset.
 
@@ -553,7 +564,8 @@ class Dataset:
 
         Example
         -------
-        >>> items, err, msg = dataset.list_items(dataset_version="v1.0", page_size=10, page_number=0)
+        >>> items, err, msg = dataset.list_items(dataset_version="v1.0", page_size=10,
+        page_number=0)
         >>> if err:
         >>>     pprint(err)
         >>> else:
@@ -564,17 +576,20 @@ class Dataset:
                 "Dataset id not set for this dataset. Cannot perform the operation for dataset without dataset id"
             )
             sys.exit(0)
-
         path = f"v1/dataset/{self.dataset_id}/version/{dataset_version}/v2/item?Size={page_size}&pageNumber={page_number}&projectId={self.project_id}"
         resp = self.rpc.get(path=path)
-
         return handle_response(
             resp,
             f"Dataset items for version - {dataset_version} fetched successfully",
             "Could not fetch dataset items",
         )
 
-    def list_items(self, dataset_version, page_size = 10, page_number = 0):
+    def list_items(
+        self,
+        dataset_version,
+        page_size=10,
+        page_number=0,
+    ):
         """
         List items for a specific version of the dataset.
 
@@ -605,7 +620,8 @@ class Dataset:
 
         Example
         -------
-        >>> items, err, msg = dataset.list_items(dataset_version="v1.0", page_size=10, page_number=0)
+        >>> items, err, msg = dataset.list_items(dataset_version="v1.0", page_size=10,
+        page_number=0)
         >>> if err:
         >>>     pprint(err)
         >>> else:
@@ -616,10 +632,8 @@ class Dataset:
                 "Dataset id not set for this dataset. Cannot perform the operation for dataset without dataset id"
             )
             sys.exit(0)
-
         path = f"v1/dataset/{self.dataset_id}/version/{dataset_version}/v2/item?Size={page_size}&pageNumber={page_number}&projectId={self.project_id}"
         resp = self.rpc.get(path=path)
-
         return handle_response(
             resp,
             f"Dataset items for version - {dataset_version} fetched successfully",
@@ -630,7 +644,8 @@ class Dataset:
         """
         Get all processed versions of the dataset.
 
-        This function retrieves a list of all versions of the dataset that have completed processing.
+        This function retrieves a list of all versions of the dataset that have completed
+            processing.
 
         Returns
         -------
@@ -645,10 +660,12 @@ class Dataset:
                 - `name` (str): Name of the dataset.
                 - `processedVersions` (list of str): List of processed versions.
                 - `stats` (list of dict): Version-specific statistics, including:
-                    - `classStat` (dict): Contains category-specific counts for `test`, `train`, `unassigned`, and `val`.
+                    - `classStat` (dict): Contains category-specific counts for `test`, `train`,
+                    `unassigned`, and `val`.
                     - `version` (str): Version identifier.
                     - `versionDescription` (str): Description of the version.
-                    - `versionStats` (dict): Overall statistics, including `total`, `train`, `test`, and `val` counts.
+                    - `versionStats` (dict): Overall statistics, including `total`, `train`, `test`,
+                    and `val` counts.
                     - `versionStatus` (str): Status of the version, usually "processed".
                 - `updatedAt` (str): Timestamp of the last dataset update.
             - str or None: Error message if an error occurred, `None` otherwise.
@@ -666,10 +683,12 @@ class Dataset:
         >>>     pprint(err)
         >>> else:
         >>>     pprint(processed_versions[:3])
-        >>> 
+        >>>
         >>> # Sample output
         >>> [
-        >>>     {'_id': '6703af894ddeac5b596b267b', '_idProject': '67036673ccb244bee86d1939', 'allVersions': ['v1.0', 'v1.1'], 'createdAt': '2024-10-07T09:53:13.223Z', 'name': 'Microcontroller', 'processedVersions': ['v1.1'], 'latestVersion': 'v1.1', ...},
+        >>>     {'_id': '6703af894ddeac5b596b267b', '_idProject': '67036673ccb244bee86d1939',
+        'allVersions': ['v1.0', 'v1.1'], 'createdAt': '2024-10-07T09:53:13.223Z',
+        'name': 'Microcontroller', 'processedVersions': ['v1.1'], 'latestVersion': 'v1.1', ...},
         >>>     ...
         >>> ]
         """
@@ -678,13 +697,11 @@ class Dataset:
                 "Dataset id not set for this dataset. Cannot perform the operation for dataset without dataset id"
             )
             sys.exit(0)
-
         path = f"/v1/dataset/get_processed_versions?projectId={self.project_id}"
         resp = self.rpc.get(path=path)
-
         return handle_response(
             resp,
-            f"Processed versions fetched successfully",
+            "Processed versions fetched successfully",
             "Could not fetch processed versions",
         )
 
@@ -721,7 +738,7 @@ class Dataset:
         >>>     pprint(err)
         >>> else:
         >>>     pprint(split_status)
-        >>> 
+        >>>
         >>> # Sample output
         >>>     'Valid Spilts'
         """
@@ -730,12 +747,13 @@ class Dataset:
                 "Dataset id not set for this dataset. Cannot perform the operation for dataset without dataset id"
             )
             sys.exit(0)
-
         path = f"/v1/dataset/check_valid_spilts/{self.dataset_id}/{dataset_version}?projectId={self.project_id}"
         resp = self.rpc.get(path=path)
-
-        return handle_response(resp, f"Splits are valid", "Splits are invalid")
-
+        return handle_response(
+            resp,
+            "Splits are valid",
+            "Splits are invalid",
+        )
 
     def _get_dataset_by_name(self):
         """
@@ -774,7 +792,7 @@ class Dataset:
         >>>     pprint(err)
         >>> else:
         >>>     pprint(dataset_details)
-        >>> 
+        >>>
         >>> # Sample output
         >>> {
         >>>     '_id': '671636dd5cffa65a7510a52b',
@@ -789,18 +807,14 @@ class Dataset:
                 "Dataset name not set for this dataset. Cannot perform the operation for dataset without dataset name"
             )
             sys.exit(0)
-
         path = f"/v1/dataset/get_dataset_by_name?datasetName={self.dataset_name}&projectId={self.project_id}"
         resp = self.rpc.get(path=path)
         return handle_response(
             resp,
-            f"Dataset Details Fetched successfully",
+            "Dataset Details Fetched successfully",
             "Could not fetch dataset details",
         )
 
-    
-    # PUT REQUESTS
-
     def rename(self, updated_name):
         """
         Update the name of the dataset.
@@ -821,7 +835,8 @@ class Dataset:
                 - `MatchedCount` (int): Number of records matched for the update.
                 - `ModifiedCount` (int): Number of records modified.
                 - `UpsertedCount` (int): Number of records upserted (inserted if not existing).
-                - `UpsertedID` (str or None): ID of the upserted record if applicable, otherwise `None`.
+                - `UpsertedID` (str or None): ID of the upserted record if applicable,
+                otherwise `None`.
             - str or None: Error message if an error occurred, `None` otherwise.
             - str: Status message indicating success or failure.
 
@@ -837,7 +852,7 @@ class Dataset:
         >>>     pprint(err)
         >>> else:
         >>>     pprint(response)
-        >>> 
+        >>>
         >>> # Sample output
         >>> {
         >>>     'MatchedCount': 1,
@@ -851,12 +866,14 @@ class Dataset:
                 "Dataset id not set for this dataset. Cannot perform the operation for dataset without dataset id"
             )
             sys.exit(0)
-
         path = f"/v1/dataset/{self.dataset_id}?projectId={self.project_id}"
         headers = {"Content-Type": "application/json"}
         body = {"name": updated_name}
-        resp = self.rpc.put(path=path, headers=headers, payload=body)
-
+        resp = self.rpc.put(
+            path=path,
+            headers=headers,
+            payload=body,
+        )
         return handle_response(
             resp,
             f"Successfully updated dataset name to {updated_name}",
@@ -867,7 +884,7 @@ class Dataset:
         """
         Update the label of a specific dataset item.
 
-        This function assigns a new label to a specific item in a specified dataset version. 
+        This function assigns a new label to a specific item in a specified dataset version.
         The dataset ID must be set during initialization for this function to work.
 
         Parameters
@@ -894,7 +911,8 @@ class Dataset:
 
         Example
         -------
-        >>> response, err, msg = dataset.update_item_label(dataset_version="v1.0", item_id="12345", label_id="67890")
+        >>> response, err, msg = dataset.update_item_label(dataset_version="v1.0", item_id="12345",
+        label_id="67890")
         >>> if err:
         >>>     pprint(err)
         >>> else:
@@ -905,19 +923,20 @@ class Dataset:
                 "Dataset id not set for this dataset. Cannot perform the operation for dataset without dataset id"
             )
             sys.exit(0)
-
         path = f"/v1/dataset/{self.dataset_id}/version/{dataset_version}/item/{item_id}/label?projectId={self.project_id}"
         headers = {"Content-Type": "application/json"}
         body = {"labelId": label_id}
-        resp = self.rpc.put(path=path, headers=headers, payload=body)
-
+        resp = self.rpc.put(
+            path=path,
+            headers=headers,
+            payload=body,
+        )
         return handle_response(
             resp,
             "Update data item label in progress",
             "Could not update the date item label",
         )
 
-    # POST REQUESTS
     def add_data(
         self,
         source,
@@ -929,10 +948,13 @@ class Dataset:
         compute_alias="",
     ):
         """
-        Import a new version of the dataset from an external source. Only ZIP files are supported for upload.
+        Import a new version of the dataset from an external source. Only ZIP files are supported
+            for upload.
 
-        This function creates a new dataset version or updates an existing version with data from a specified
-        external source URL. The dataset ID must be set during initialization for this function to work.
+        This function creates a new dataset version or updates an existing version with data from a
+            specified
+        external source URL. The dataset ID must be set during initialization for this function to
+            work.
 
         Parameters
         ----------
@@ -982,28 +1004,23 @@ class Dataset:
                 "Dataset id not set for this dataset. Cannot perform the operation for dataset without dataset id"
             )
             sys.exit(0)
-
         dataset_resp, err, message = self._get_dataset()
         if err is not None:
             return dataset_resp, err, message
-
         stats = dataset_resp["stats"]
         if dataset_description == "":
             dataset_description = dataset_resp["datasetDesc"]
-
         for stat in stats:
             if stat["version"] != old_dataset_version:
                 continue
             if stat["versionStatus"] != "processed":
                 resp = {}
                 err = None
-                message = f"Only the dataset versions with complete status can be updated.Version {old_dataset_version} of the dataset doesn't have status complete."
+                message = f"Only the dataset versions with complete status can be updated. Version {old_dataset_version} of the dataset doesn't have status complete."
                 return resp, err, message
-
             if version_description == "" and old_dataset_version == new_dataset_version:
                 version_description = stat["versionDescription"]
             break
-
         is_created_new = new_dataset_version == old_dataset_version
         path = f"v1/dataset/{self.dataset_id}/import?project={self.project_id}"
         headers = {"Content-Type": "application/json"}
@@ -1018,8 +1035,11 @@ class Dataset:
             "datasetDesc": dataset_description,
             "computeAlias": compute_alias,
         }
-        resp = self.rpc.post(path=path, headers=headers, payload=body)
-
+        resp = self.rpc.post(
+            path=path,
+            headers=headers,
+            payload=body,
+        )
         return handle_response(
             resp,
             "New data item addition in progress",
@@ -1034,7 +1054,13 @@ class Dataset:
         train_num=0,
         val_num=0,
         test_num=0,
-        transfers=[{"source": "", "destination": "", "transferAmount": 1}],
+        transfers=[
+            {
+                "source": "",
+                "destination": "",
+                "transferAmount": 1,
+            }
+        ],
         dataset_description="",
         version_description="",
         new_version_description="",
@@ -1043,8 +1069,10 @@ class Dataset:
         """
         Split or transfer images between training, validation, and test sets in the dataset.
 
-        This function enables the creation of a new dataset version by transferring or splitting images from an existing 
-        version into training, validation, and test sets, with options for random or manual split distribution.
+        This function enables the creation of a new dataset version by transferring or splitting
+            images from an existing
+        version into training, validation, and test sets, with options for random or manual split
+            distribution.
 
         Parameters
         ----------
@@ -1108,29 +1136,24 @@ class Dataset:
                 "Dataset id not set for this dataset. Cannot perform the operation for dataset without dataset id"
             )
             sys.exit(0)
-
         dataset_resp, err, message = self._get_dataset()
         if err is not None:
             return dataset_resp, err, message
-
         stats = dataset_resp["stats"]
         if dataset_description == "":
             dataset_description = dataset_resp["datasetDesc"]
-
         for stat in stats:
             if stat["version"] != old_dataset_version:
                 continue
             if stat["versionStatus"] != "processed":
                 resp = {}
                 err = None
-                message = f"Only the dataset versions with complete status can be updated.Version {old_dataset_version} of the dataset doesn't have status complete."
+                message = f"Only the dataset versions with complete status can be updated. Version {old_dataset_version} of the dataset doesn't have status complete."
                 return resp, err, message
-
             if version_description == "" and old_dataset_version == new_dataset_version:
                 version_description = stat["versionDescription"]
             break
-
-        path = f"/v1/dataset/{self.dataset_id}/split_data?projectId={self.project_id}"
+        path = f"/v2/dataset/split_data/{self.dataset_id}?projectId={self.project_id}"
         headers = {"Content-Type": "application/json"}
         body = {
             "trainNum": train_num,
@@ -1145,21 +1168,25 @@ class Dataset:
             "transfers": transfers,
             "computeAlias": compute_alias,
         }
-        resp = self.rpc.post(path=path, headers=headers, payload=body)
-
+        resp = self.rpc.post(
+            path=path,
+            headers=headers,
+            payload=body,
+        )
         return handle_response(
             resp,
             "Dataset spliting in progress",
             "An error occured while trying to split the data.",
         )
 
-    # DELETE REQUESTS
     def delete_item(self, dataset_version, dataset_item_ids):
         """
         Delete items from a specific version of the dataset based on dataset type.
 
-        This function deletes items from a specified version of the dataset. The deletion method is selected
-        automatically based on the dataset type (e.g., classification, detection). The dataset ID must be set 
+        This function deletes items from a specified version of the dataset. The deletion method is
+            selected
+        automatically based on the dataset type (e.g., classification, detection)
+        . The dataset ID must be set
         during initialization for this function to work.
 
         Parameters
@@ -1192,21 +1219,23 @@ class Dataset:
         >>> else:
         >>>     pprint(response)
         """
-        # Retrieve the dataset details to get the type
         resp, error, message = self._get_details()
         if error:
             return resp, error, message
-
-        dataset_type = resp.get('type')
-        
-        # Check dataset type and call the respective delete function
+        dataset_type = resp.get("type")
         if dataset_type == "classification":
-            return self._delete_item_classification(dataset_version, dataset_item_ids)
+            return self._delete_item_classification(
+                dataset_version,
+                dataset_item_ids,
+            )
         elif dataset_type == "detection":
             return self._delete_item_detection(dataset_version, dataset_item_ids)
         else:
-            return {}, f"Unsupported dataset type: {dataset_type}.", "Failed to delete dataset items"
-
+            return (
+                {},
+                f"Unsupported dataset type: {dataset_type}.",
+                "Failed to delete dataset items",
+            )
 
     def _delete_item_classification(self, dataset_version, dataset_item_ids):
         """
@@ -1250,15 +1279,17 @@ class Dataset:
                 "Dataset id not set for this dataset. Cannot perform the operation for dataset without dataset id"
             )
             sys.exit(0)
-
         path = f"/v1/dataset/version/{dataset_version}/dataset_item_classification?projectId={self.project_id}&datasetId={self.dataset_id}"
         requested_payload = {"datasetItemIds": dataset_item_ids}
         headers = {"Content-Type": "application/json"}
-        resp = self.rpc.delete(path=path, headers=headers, payload=requested_payload)
-
+        resp = self.rpc.delete(
+            path=path,
+            headers=headers,
+            payload=requested_payload,
+        )
         return handle_response(
             resp,
-            f"Given dataset items deleted successfully",
+            "Given dataset items deleted successfully",
             "Could not delete the given dataset items",
         )
 
@@ -1266,7 +1297,7 @@ class Dataset:
         """
         Delete items from a detection dataset version.
 
-        This function deletes specified items from a given version of a detection dataset. 
+        This function deletes specified items from a given version of a detection dataset.
         The dataset ID must be set during initialization for this function to work.
 
         Parameters
@@ -1304,15 +1335,17 @@ class Dataset:
                 "Dataset id not set for this dataset. Cannot perform the operation for dataset without dataset id"
             )
             sys.exit(0)
-
         path = f"/v1/dataset/version/{dataset_version}/dataset_item_detection?projectId={self.project_id}&datasetId={self.dataset_id}"
         requested_payload = {"datasetItemIds": dataset_item_ids}
         headers = {"Content-Type": "application/json"}
-        resp = self.rpc.delete(path=path, headers=headers, payload=requested_payload)
-
+        resp = self.rpc.delete(
+            path=path,
+            headers=headers,
+            payload=requested_payload,
+        )
         return handle_response(
             resp,
-            f"Given dataset items deleted successfully",
+            "Given dataset items deleted successfully",
             "Could not delete the given dataset items",
         )
 
@@ -1354,10 +1387,10 @@ class Dataset:
                 "Dataset id not set for this dataset. Cannot perform the operation for dataset without dataset id"
             )
             sys.exit(0)
-
-        path = f"/v1/dataset/{self.dataset_id}/version/{dataset_version}?projectId={self.project_id}"
+        path = (
+            f"/v1/dataset/{self.dataset_id}/version/{dataset_version}?projectId={self.project_id}"
+        )
         resp = self.rpc.delete(path=path)
-
         return handle_response(
             resp,
             f"Successfully deleted version - {dataset_version}",
@@ -1368,7 +1401,8 @@ class Dataset:
         """
         Delete the entire dataset.
 
-        This function deletes the entire dataset associated with the given dataset ID. The dataset ID 
+        This function deletes the entire dataset associated with the given dataset ID. The dataset
+            ID
         must be set during initialization for this function to work.
 
         Returns
@@ -1397,12 +1431,10 @@ class Dataset:
                 "Dataset id not set for this dataset. Cannot perform the operation for dataset without dataset id"
             )
             sys.exit(0)
-
         path = f"/v1/dataset/{self.dataset_id}?projectId={self.project_id}"
         resp = self.rpc.delete(path=path)
-
         return handle_response(
-            resp, f"Successfully deleted the dataset", "Could not delete the dataset"
+            resp,
+            "Successfully deleted the dataset",
+            "Could not delete the dataset",
         )
-
-
