@@ -1,27 +1,28 @@
-import time
 from typing import Any, Dict, List, Optional
-from dataclasses import dataclass, field
+from dataclasses import asdict
+import time
 from datetime import datetime, timezone
-from collections import deque
 
-# Core SDK imports
-from ..core.base import BaseProcessor, ProcessingContext, ProcessingResult, ConfigProtocol
-from ..core.config import BaseConfig, AlertConfig
-
-# Utility functions
+from ..core.base import BaseProcessor, ProcessingContext, ProcessingResult, ConfigProtocol, ResultFormat
 from ..utils import (
     filter_by_confidence,
+    filter_by_categories,
+    apply_category_mapping,
+    count_objects_by_category,
+    count_objects_in_zones,
     calculate_counting_summary,
     match_results_structure,
-    apply_category_mapping,
     bbox_smoothing,
     BBoxSmoothingConfig,
     BBoxSmoothingTracker
 )
+from dataclasses import dataclass, field
+from ..core.config import BaseConfig, AlertConfig, ZoneConfig
 
 
 @dataclass
 class ChildMonitoringConfig(BaseConfig):
+    """Configuration for child detection use case in child monitoring."""
     # Smoothing configuration
     enable_smoothing: bool = True
     smoothing_algorithm: str = "observability"  # "window" or "observability"
@@ -29,79 +30,83 @@ class ChildMonitoringConfig(BaseConfig):
     smoothing_cooldown_frames: int = 5
     smoothing_confidence_range_factor: float = 0.5
 
-    relevant_categories: List[str] = field(default_factory=lambda: ["baby"])
+    #confidence thresholds
+    confidence_threshold: float = 0.6
+
+    usecase_categories: List[str] = field(
+        default_factory=lambda: ['baby']
+    )
+
+    target_categories: List[str] = field(
+        default_factory=lambda: ['baby']
+    )
 
-    # Placeholder alert config for structural compatibility
     alert_config: Optional[AlertConfig] = None
 
-    confidence_threshold: float = 0.45
-
-    # Only relevant classes:  baby is index 0
-    index_to_category: Optional[Dict[int, str]] = field(default_factory=lambda: {
-        0: "baby"
-    })
+    index_to_category: Optional[Dict[int, str]] = field(
+        default_factory=lambda: {
+            0: "baby",
+        }
+    )
 
 
 class ChildMonitoringUseCase(BaseProcessor):
+    def _get_track_ids_info(self, detections: list) -> Dict[str, Any]:
+        """
+        Get detailed information about track IDs (per frame).
+        """
+        # Collect all track_ids in this frame
+        frame_track_ids = set()
+        for det in detections:
+            tid = det.get('track_id')
+            if tid is not None:
+                frame_track_ids.add(tid)
+        # Use persistent total set for unique counting
+        total_track_ids = set()
+        for s in getattr(self, '_per_category_total_track_ids', {}).values():
+            total_track_ids.update(s)
+        return {
+            "total_count": len(total_track_ids),
+            "current_frame_count": len(frame_track_ids),
+            "total_unique_track_ids": len(total_track_ids),
+            "current_frame_track_ids": list(frame_track_ids),
+            "last_update_time": time.time(),
+            "total_frames_processed": getattr(self, '_total_frame_counter', 0)
+        }
 
-    def __init__(self):
-        super().__init__("child_monitoring")
-        self.category = "security"
 
-        # List of categories to track (same as config; retained for local use)
-        self.relevant_categories = ["baby"]
 
-        # Smoothing tracker (created on-demand if enabled)
-        self.smoothing_tracker = None
 
-        # Advanced tracker (will be created on first use)
-        self.tracker = None
 
-        # Internal tracking state variables
-        self._total_frame_counter = 0
-        self._global_frame_offset = 0
-
-        # Set of all unique track_ids seen so far
-        self._total_child_track_ids = set()
-
-        # Set of current frame track_ids (updated per frame)
-        self._current_frame_track_ids = set()
-
-        # Track start time for "TOTAL SINCE" calculation
-        self._tracking_start_time = None
-
-        # ------------------------------------------------------------------ #
-        # Canonical tracking aliasing to avoid duplicate counts              #
-        # ------------------------------------------------------------------ #
-        # Maps raw tracker-generated IDs to stable canonical IDs that persist
-        # even if the underlying tracker re-assigns a new ID after a short
-        # interruption. This mirrors the logic used in people_counting to
-        # provide accurate unique counting.
-        self._track_aliases: Dict[Any, Any] = {}
-        self._canonical_tracks: Dict[Any, Dict[str, Any]] = {}
-        # Tunable parameters – adjust if necessary for specific scenarios
-        self._track_merge_iou_threshold: float = 0.3  # IoU ≥ 0.05 
-        self._track_merge_time_window: float = 2.0  # seconds within which to merge
-
-    def _update_tracking_state(self, detections: List[Dict[str, Any]]) -> None:
-        self._current_frame_track_ids = set()
+    def _update_tracking_state(self, detections: list):
+        """
+        Track unique categories track_ids per category for total count after tracking.
+        Applies canonical ID merging to avoid duplicate counting when the underlying
+        tracker loses an object temporarily and assigns a new ID.
+        """
+        # Lazily initialise storage dicts
+        if not hasattr(self, "_per_category_total_track_ids"):
+            self._per_category_total_track_ids = {cat: set() for cat in self.target_categories}
+        self._current_frame_track_ids = {cat: set() for cat in self.target_categories}
 
         for det in detections:
             cat = det.get("category")
             raw_track_id = det.get("track_id")
-            if cat not in self.relevant_categories or raw_track_id is None:
+            if cat not in self.target_categories or raw_track_id is None:
                 continue
-
             bbox = det.get("bounding_box", det.get("bbox"))
             canonical_id = self._merge_or_register_track(raw_track_id, bbox)
-            det["track_id"] = canonical_id  # Propagate for downstream
+            # Propagate canonical ID back to detection so downstream logic uses it
+            det["track_id"] = canonical_id
 
-            
-            self._total_child_track_ids.add(canonical_id)
-            self._current_frame_track_ids.add(canonical_id)
-    
-    def get_total_child_count(self) -> int:
-        return len(self._total_child_track_ids)
+            self._per_category_total_track_ids.setdefault(cat, set()).add(canonical_id)
+            self._current_frame_track_ids[cat].add(canonical_id)
+
+    def get_total_counts(self):
+        """
+        Return total unique track_id count for each category.
+        """
+        return {cat: len(ids) for cat, ids in getattr(self, '_per_category_total_track_ids', {}).items()}
 
     def _format_timestamp_for_video(self, timestamp: float) -> str:
         """Format timestamp for video chunks (HH:MM:SS.ms format)."""
@@ -182,57 +187,78 @@ class ChildMonitoringUseCase(BaseProcessor):
             dt = dt.replace(minute=0, second=0, microsecond=0)
             return dt.strftime('%Y:%m:%d %H:%M:%S')
 
-    def _get_track_ids_info(self, detections: list) -> dict:
-        frame_track_ids = set()
-        for det in detections:
-            tid = det.get("track_id")
-            if tid is not None:
-                frame_track_ids.add(tid)
+    """ Monitoring use case with smoothing and alerting."""
 
-        # Update total unique track ids set
-        self._total_child_track_ids.update(frame_track_ids)
+    def __init__(self):
+        super().__init__("child_monitoring")
+        self.category = "security"
 
-        return {
-            "frame_track_ids": list(frame_track_ids),  #  JSON-serializable
-            "total_unique_track_ids": list(self._total_child_track_ids),  #  JSON-serializable
-            "frame_track_ids_count": len(frame_track_ids),
-            "total_unique_count": len(self._total_child_track_ids),
-        }
+        # List of  categories to track
+        self.target_categories = ['baby']
 
-    def process(
-            self,
-            data: Any,
-            config: ConfigProtocol,
-            context: Optional[ProcessingContext] = None,
-            stream_info: Optional[Dict[str, Any]] = None
-    ) -> ProcessingResult:
 
+
+        # Initialize smoothing tracker
+        self.smoothing_tracker = None
+
+        # Initialize advanced tracker (will be created on first use)
+        self.tracker = None
+
+        # Initialize tracking state variables
+        self._total_frame_counter = 0
+        self._global_frame_offset = 0
+
+        # Track start time for "TOTAL SINCE" calculation
+        self._tracking_start_time = None
+
+        # ------------------------------------------------------------------ #
+        # Canonical tracking aliasing to avoid duplicate counts              #
+        # ------------------------------------------------------------------ #
+        # Maps raw tracker-generated IDs to stable canonical IDs that persist
+        # even if the underlying tracker re-assigns a new ID after a short
+        # interruption. This mirrors the logic used in people_counting to
+        # provide accurate unique counting.
+        self._track_aliases: Dict[Any, Any] = {}
+        self._canonical_tracks: Dict[Any, Dict[str, Any]] = {}
+        # Tunable parameters – adjust if necessary for specific scenarios
+        self._track_merge_iou_threshold: float = 0.05  # IoU ≥ 0.05 →
+        self._track_merge_time_window: float = 7.0  # seconds within which to merge
+
+    def process(self, data: Any, config: ConfigProtocol, context: Optional[ProcessingContext] = None,
+                stream_info: Optional[Dict[str, Any]] = None) -> ProcessingResult:
+        """
+        Main entry point for  post-processing.
+        Applies category mapping, smoothing, counting, alerting, and summary generation.
+        Returns a ProcessingResult with all relevant outputs.
+        """
         start_time = time.time()
-
+        # Ensure config is correct type
         if not isinstance(config, ChildMonitoringConfig):
             return self.create_error_result("Invalid config type", usecase=self.name, category=self.category,
                                             context=context)
-
         if context is None:
             context = ProcessingContext()
 
         # Detect input format and store in context
         input_format = match_results_structure(data)
         context.input_format = input_format
+        context.confidence_threshold = config.confidence_threshold
 
-        # Map detection indices to category names if needed
-        processed_data = apply_category_mapping(data, config.index_to_category)
-        # Handle stringified numeric categories like "0"
-        for det in processed_data:
-            cat = det.get("category")
-            if isinstance(cat, str) and cat.isdigit():
-                det["category"] = config.index_to_category.get(int(cat), cat)
+        if config.confidence_threshold is not None:
+            processed_data = filter_by_confidence(data, config.confidence_threshold)
+            self.logger.debug(f"Applied confidence filtering with threshold {config.confidence_threshold}")
+        else:
+            processed_data = data
+            self.logger.debug(f"Did not apply confidence filtering with threshold since nothing was provided")
 
-        # Filter only relevant category (baby)
-        processed_data = [
-            d for d in processed_data
-            if d.get("category") in self.relevant_categories
-        ]
+        # Step 2: Apply category mapping if provided
+        if config.index_to_category:
+            processed_data = apply_category_mapping(processed_data, config.index_to_category)
+            self.logger.debug("Applied category mapping")
+
+        if config.target_categories:
+            processed_data = [d for d in processed_data if d.get('category') in self.target_categories]
+            self.logger.debug(f"Applied  category filtering")
 
         # Apply bbox smoothing if enabled
         if config.enable_smoothing:
@@ -241,75 +267,81 @@ class ChildMonitoringUseCase(BaseProcessor):
                     smoothing_algorithm=config.smoothing_algorithm,
                     window_size=config.smoothing_window_size,
                     cooldown_frames=config.smoothing_cooldown_frames,
-                    confidence_threshold=0.5,  # Reasonable default
+                    confidence_threshold=config.confidence_threshold,  # Use mask threshold as default
                     confidence_range_factor=config.smoothing_confidence_range_factor,
                     enable_smoothing=True
                 )
                 self.smoothing_tracker = BBoxSmoothingTracker(smoothing_config)
+            processed_data = bbox_smoothing(processed_data, self.smoothing_tracker.config, self.smoothing_tracker)
 
-            processed_data = bbox_smoothing(
-                processed_data,
-                self.smoothing_tracker.config,
-                self.smoothing_tracker
-            )
 
-        # Apply advanced tracking
+        # Advanced tracking (BYTETracker-like)
         try:
             from ..advanced_tracker import AdvancedTracker
             from ..advanced_tracker.config import TrackerConfig
 
+            # Create tracker instance if it doesn't exist (preserves state across frames)
             if self.tracker is None:
                 tracker_config = TrackerConfig()
                 self.tracker = AdvancedTracker(tracker_config)
-                self.logger.info("Initialized AdvancedTracker for Child tracking")
+                self.logger.info("Initialized AdvancedTracker for  Monitoring and tracking")
 
+            # The tracker expects the data in the same format as input
+            # It will add track_id and frame_id to each detection
             processed_data = self.tracker.update(processed_data)
-            self.logger.info(f"AdvancedTracker processed {len(processed_data)} detections")
 
         except Exception as e:
+            # If advanced tracker fails, fallback to unsmoothed detections
             self.logger.warning(f"AdvancedTracker failed: {e}")
 
-        # Update tracking state
+
+
+
+        # Update  tracking state for total count per label
         self._update_tracking_state(processed_data)
 
         # Update frame counter
         self._total_frame_counter += 1
 
-        # Extract frame number from stream_info
+        # Extract frame information from stream_info
         frame_number = None
         if stream_info:
             input_settings = stream_info.get("input_settings", {})
             start_frame = input_settings.get("start_frame")
             end_frame = input_settings.get("end_frame")
+            # If start and end frame are the same, it's a single frame
             if start_frame is not None and end_frame is not None and start_frame == end_frame:
                 frame_number = start_frame
 
-        # Compute summaries
-        general_counting_summary = calculate_counting_summary(data)
-        counting_summary = self._count_categories(processed_data, config)
-        total_unique = self.get_total_child_count()
-        counting_summary["total_child_count"] = total_unique
+        # Compute summaries and alerts
+        general_counting_summary = calculate_counting_summary(data) #done
+        counting_summary = self._count_categories(processed_data, config) #done
+        # Add total unique  counts after tracking using only local state
+        total_counts = self.get_total_counts() #done
+        counting_summary['total_counts'] = total_counts #done
+        insights = self._generate_insights(counting_summary, config)#done
+        alerts = self._check_alerts(counting_summary, config)#done
+        predictions = self._extract_predictions(processed_data)#done
+        summary = self._generate_summary(counting_summary, alerts)#done
 
-        insights = self._generate_insights(counting_summary, config)
-        alerts = []  
-        predictions = self._extract_predictions(processed_data)
-        summary = self._generate_summary(counting_summary, alerts)
-
-        events_list = self._generate_events(counting_summary, alerts, config, frame_number, stream_info)
+        # Step: Generate structured events and tracking stats with frame-based keys
+        events_list = self._generate_events(counting_summary, alerts, config, frame_number, stream_info)#done
         tracking_stats_list = self._generate_tracking_stats(counting_summary, insights, summary, config, frame_number,
                                                             stream_info)
 
+        # Extract frame-based dictionaries from the lists
         events = events_list[0] if events_list else {}
         tracking_stats = tracking_stats_list[0] if tracking_stats_list else {}
 
         context.mark_completed()
 
+        # Build result object
         result = self.create_result(
             data={
                 "counting_summary": counting_summary,
                 "general_counting_summary": general_counting_summary,
                 "alerts": alerts,
-                "total_violations": counting_summary.get("total_count", 0),
+                "total_detections": counting_summary.get("total_count", 0),
                 "events": events,
                 "tracking_stats": tracking_stats,
             },
@@ -322,65 +354,107 @@ class ChildMonitoringUseCase(BaseProcessor):
         result.predictions = predictions
         return result
 
-    def reset_tracker(self) -> None:
-        """
-        Reset the advanced tracker instance.
-        """
-        if self.tracker is not None:
-            self.tracker.reset()
-            self.logger.info("AdvancedTracker reset for new child session")
 
-    def reset_tracking_state(self) -> None:
-        self._total_child_track_ids = set()
-        self._total_frame_counter = 0
-        self._global_frame_offset = 0
-        self._tracking_start_time = None
-        self._track_aliases.clear()
-        self._canonical_tracks.clear()
-        self.logger.info("Child tracking state reset")
 
-    def reset_all_tracking(self) -> None:
-        """
-        Reset both advanced tracker and tracking state.
-        """
-        self.reset_tracker()
-        self.reset_tracking_state()
-        self.logger.info("All child tracking state reset")
-
-    def _generate_events(
-            self,
-            counting_summary: Dict,
-            alerts: List,
-            config: ChildMonitoringConfig,
-            frame_number: Optional[int] = None,
-            stream_info: Optional[Dict[str, Any]] = None
-    ) -> List[Dict]:
-        """Generate structured events for the output format with frame-based keys (no alerts for child)."""
+    def _generate_events(self, counting_summary: Dict, alerts: List, config: ChildMonitoringConfig,
+                         frame_number: Optional[int] = None, stream_info: Optional[Dict[str, Any]] = None) -> List[
+        Dict]:
+        """Generate structured events for the output format with frame-based keys."""
         from datetime import datetime, timezone
 
         # Use frame number as key, fallback to 'current_frame' if not available
         frame_key = str(frame_number) if frame_number is not None else "current_frame"
         events = [{frame_key: []}]
         frame_events = events[0][frame_key]
-        total_count = counting_summary.get("total_count", 0)
+        total_detections = counting_summary.get("total_count", 0)
+
+        if total_detections > 0:
+            # Determine event level based on thresholds
+            level = "info"
+            intensity = 5.0
+            if config.alert_config and config.alert_config.count_thresholds:
+                threshold = config.alert_config.count_thresholds.get("all", 15)
+                intensity = min(10.0, (total_detections / threshold) * 10)
+
+                if intensity >= 7:
+                    level = "critical"
+                elif intensity >= 5:
+                    level = "warning"
+                else:
+                    level = "info"
+            else:
+                if total_detections > 25:
+                    level = "critical"
+                    intensity = 9.0
+                elif total_detections > 15:
+                    level = "warning"
+                    intensity = 7.0
+                else:
+                    level = "info"
+                    intensity = min(10.0, total_detections / 3.0)
 
-        if total_count > 0:
             # Generate human text in new format
             human_text_lines = ["EVENTS DETECTED:"]
-            human_text_lines.append(f"    - {total_count} child(s) detected [INFO]")
+            human_text_lines.append(f"    - {total_detections}  detected [INFO]")
             human_text = "\n".join(human_text_lines)
 
             event = {
                 "type": "child_monitoring",
-                "severity": "info",
-                "category": "security",
-                "count": total_count,
-                "timestamp": datetime.now(timezone.utc).strftime('%Y-%m-%d-%H:%M:%S UTC'),
+                "stream_time": datetime.now(timezone.utc).strftime("%Y-%m-%d-%H:%M:%S UTC"),
+                "level": level,
+                "intensity": round(intensity, 1),
+                "config": {
+                    "min_value": 0,
+                    "max_value": 10,
+                    "level_settings": {"info": 2, "warning": 5, "critical": 7}
+                },
+                "application_name": "mask detection System",
+                "application_version": "1.2",
                 "location_info": None,
                 "human_text": human_text
             }
             frame_events.append(event)
 
+        # Add alert events
+        for alert in alerts:
+            total_detections = counting_summary.get("total_count", 0)
+            intensity_message = "ALERT: Low congestion in the scene"
+            if config.alert_config and config.alert_config.count_thresholds:
+                threshold = config.alert_config.count_thresholds.get("all", 15)
+                percentage = (total_detections / threshold) * 100 if threshold > 0 else 0
+                if percentage < 20:
+                    intensity_message = "ALERT: Low congestion in the scene"
+                elif percentage <= 50:
+                    intensity_message = "ALERT: Moderate congestion in the scene"
+                elif percentage <= 70:
+                    intensity_message = "ALERT: Heavy congestion in the scene"
+                else:
+                    intensity_message = "ALERT: Severe congestion in the scene"
+            else:
+                if total_detections > 15:
+                    intensity_message = "ALERT: Heavy congestion in the scene"
+                elif total_detections == 1:
+                    intensity_message = "ALERT: Low congestion in the scene"
+                else:
+                    intensity_message = "ALERT: Moderate congestion in the scene"
+
+            alert_event = {
+                "type": alert.get("type", "congestion_alert"),
+                "stream_time": datetime.now(timezone.utc).strftime("%Y-%m-%d-%H:%M:%S UTC"),
+                "level": alert.get("severity", "warning"),
+                "intensity": 8.0,
+                "config": {
+                    "min_value": 0,
+                    "max_value": 10,
+                    "level_settings": {"info": 2, "warning": 5, "critical": 7}
+                },
+                "application_name": "Congestion Alert System",
+                "application_version": "1.2",
+                "location_info": alert.get("zone"),
+                "human_text": f"{datetime.now(timezone.utc).strftime('%Y-%m-%d-%H:%M:%S UTC')} : {intensity_message}"
+            }
+            frame_events.append(alert_event)
+
         return events
 
     def _generate_tracking_stats(
@@ -392,62 +466,78 @@ class ChildMonitoringUseCase(BaseProcessor):
             frame_number: Optional[int] = None,
             stream_info: Optional[Dict[str, Any]] = None
     ) -> List[Dict]:
-        """Generate structured tracking stats with frame-based keys, including per-frame and cumulative counts."""
-
+        """Generate structured tracking stats for the output format with frame-based keys, including track_ids_info."""
         frame_key = str(frame_number) if frame_number is not None else "current_frame"
         tracking_stats = [{frame_key: []}]
         frame_tracking_stats = tracking_stats[0][frame_key]
 
-        per_frame_count = counting_summary.get("total_count", 0)
-        total_unique = counting_summary.get("total_child_count", 0)
+        total_detections = counting_summary.get("total_count", 0)
+        total_counts = counting_summary.get("total_counts", {})
+        cumulative_total = sum(total_counts.values()) if total_counts else 0
+        per_category_count = counting_summary.get("per_category_count", {})
 
-        # Always get track ID info even if 0 detections — to ensure consistency
         track_ids_info = self._get_track_ids_info(counting_summary.get("detections", []))
 
-        # Get formatted timestamps
         current_timestamp = self._get_current_timestamp_str(stream_info)
         start_timestamp = self._get_start_timestamp_str(stream_info)
 
-        # Build human-readable summary string with consistent tabbed format
         human_text_lines = []
 
         # CURRENT FRAME section
         human_text_lines.append(f"CURRENT FRAME @ {current_timestamp}:")
-        if per_frame_count > 0:
-            human_text_lines.append(f"\t- Child Detected: {per_frame_count}")
+        if total_detections > 0:
+            category_counts = [f"{count} {cat}" for cat, count in per_category_count.items()]
+            if len(category_counts) == 1:
+                detection_text = category_counts[0] + " detected"
+            elif len(category_counts) == 2:
+                detection_text = f"{category_counts[0]} and {category_counts[1]} detected"
+            else:
+                detection_text = f"{', '.join(category_counts[:-1])}, and {category_counts[-1]} detected"
+            human_text_lines.append(f"\t- {detection_text}")
         else:
-            human_text_lines.append("\t- No child detected")
+            human_text_lines.append(f"\t- No detections")
 
-        human_text_lines.append("")  # Empty line for spacing
+        human_text_lines.append("")  # spacing
 
         # TOTAL SINCE section
         human_text_lines.append(f"TOTAL SINCE {start_timestamp}:")
-        human_text_lines.append(f"\t- Total child Detected: {total_unique}")
+        human_text_lines.append(f"\t- Total  Detected: {cumulative_total}")
+        # Add category-wise counts
+        if total_counts:
+            for cat, count in total_counts.items():
+                if count > 0:  # Only include categories with non-zero counts
+                    human_text_lines.append(f"\t- {cat}: {count}")
 
         human_text = "\n".join(human_text_lines)
 
         tracking_stat = {
-            "type": "child_tracking",
-            "category": "child",
-            "count": per_frame_count,
+            "type": "child_monitoring",
+            "category": "security",
+            "count": total_detections,
             "insights": insights,
             "summary": summary,
             "timestamp": datetime.now(timezone.utc).strftime('%Y-%m-%d-%H:%M:%S UTC'),
             "human_text": human_text,
             "track_ids_info": track_ids_info,
-            "global_frame_offset": getattr(self, "_global_frame_offset", 0),
-            "local_frame_id": frame_key
+            "global_frame_offset": getattr(self, '_global_frame_offset', 0),
+            "local_frame_id": frame_key,
+            "detections": counting_summary.get("detections", [])  # Added line to include detections
         }
 
         frame_tracking_stats.append(tracking_stat)
         return tracking_stats
 
     def _count_categories(self, detections: list, config: ChildMonitoringConfig) -> dict:
+        """
+        Count the number of detections per category and return a summary dict.
+        The detections list is expected to have 'track_id' (from tracker), 'category', 'bounding_box', etc.
+        Output structure will include 'track_id' for each detection as per AdvancedTracker output.
+        """
         counts = {}
         for det in detections:
             cat = det.get('category', 'unknown')
             counts[cat] = counts.get(cat, 0) + 1
-
+        # Each detection dict will now include 'track_id' (and possibly 'frame_id')
         return {
             "total_count": sum(counts.values()),
             "per_category_count": counts,
@@ -463,15 +553,82 @@ class ChildMonitoringUseCase(BaseProcessor):
             ]
         }
 
+    # Human-friendly display names for  categories
+    CATEGORY_DISPLAY = {
+        "baby": "Baby",
+    }
+
     def _generate_insights(self, summary: dict, config: ChildMonitoringConfig) -> List[str]:
+        """
+        Generate human-readable insights for each category.
+        """
         insights = []
         per_cat = summary.get("per_category_count", {})
+        total_detections = summary.get("total_count", 0)
+
+        if total_detections == 0:
+            insights.append("No detections in the scene")
+            return insights
+        insights.append(f"EVENT: Detected {total_detections}  in the scene")
+        # Intensity calculation based on threshold percentage
+        intensity_threshold = None
+        if (config.alert_config and
+                config.alert_config.count_thresholds and
+                "all" in config.alert_config.count_thresholds):
+            intensity_threshold = config.alert_config.count_thresholds["all"]
+
+        if intensity_threshold is not None:
+            # Calculate percentage relative to threshold
+            percentage = (total_detections / intensity_threshold) * 100
+
+            if percentage < 20:
+                insights.append(f"INTENSITY: Low congestion in the scene ({percentage:.1f}% of capacity)")
+            elif percentage <= 50:
+                insights.append(f"INTENSITY: Moderate congestion in the scene ({percentage:.1f}% of capacity)")
+            elif percentage <= 70:
+                insights.append(f"INTENSITY:  Heavy congestion in the scene ({percentage:.1f}% of capacity)")
+            else:
+                insights.append(f"INTENSITY: Severe congestion in the scene ({percentage:.1f}% of capacity)")
+
+
         for cat, count in per_cat.items():
-            insights.append(f"{cat}: {count} detected")
+            display = self.CATEGORY_DISPLAY.get(cat, cat)
+            insights.append(f"{display}:{count}")
         return insights
 
     def _check_alerts(self, summary: dict, config: ChildMonitoringConfig) -> List[Dict]:
-        return []
+        """
+        Check if any alert thresholds are exceeded and return alert dicts.
+        """
+        alerts = []
+        if not config.alert_config:
+            return alerts
+        total = summary.get("total_count", 0)
+        if config.alert_config.count_thresholds:
+            for category, threshold in config.alert_config.count_thresholds.items():
+                if category == "all" and total >= threshold:
+                    timestamp = datetime.now(timezone.utc).strftime('%Y-%m-%d-%H:%M:%S UTC')
+                    alert_description = f"detections count ({total}) exceeds threshold ({threshold})"
+                    alerts.append({
+                        "type": "count_threshold",
+                        "severity": "warning",
+                        "message": f"Total detections count ({total}) exceeds threshold ({threshold})",
+                        "category": category,
+                        "current_count": total,
+                        "threshold": threshold
+                    })
+                elif category in summary.get("per_category_count", {}):
+                    count = summary.get("per_category_count", {})[category]
+                    if count >= threshold:
+                        alerts.append({
+                            "type": "count_threshold",
+                            "severity": "warning",
+                            "message": f"{category} count ({count}) exceeds threshold ({threshold})",
+                            "category": category,
+                            "current_count": count,
+                            "threshold": threshold
+                        })
+        return alerts
 
     def _extract_predictions(self, detections: list) -> List[Dict[str, Any]]:
         """
@@ -487,30 +644,32 @@ class ChildMonitoringUseCase(BaseProcessor):
         ]
 
     def _generate_summary(self, summary: dict, alerts: List) -> str:
+        """
+        Generate a human_text string for the result, including per-category insights if available.
+        Adds a tab before each  label for better formatting.
+        Also always includes the cumulative count so far.
+        """
         total = summary.get("total_count", 0)
         per_cat = summary.get("per_category_count", {})
-        cumulative_total = summary.get("total_child_count", 0)
-
+        cumulative = summary.get("total_counts", {})
+        cumulative_total = sum(cumulative.values()) if cumulative else 0
         lines = []
-
         if total > 0:
-            lines.append(f"{total} child(s) detected in this frame")
+            lines.append(f"{total} detections")
             if per_cat:
                 lines.append("detections:")
                 for cat, count in per_cat.items():
-                    label = "Child"
-                    lines.append(f"\t{label}:{count}")
+                    lines.append(f"\t{cat}:{count}")
         else:
-            lines.append("No child detected in this frame")
-
-        lines.append(f"Total unique child detected: {cumulative_total}")
-
+            lines.append("No  detections")
+        lines.append(f"Total detections: {cumulative_total}")
+        if alerts:
+            lines.append(f"{len(alerts)} alert(s)")
         return "\n".join(lines)
 
-        # ------------------------------------------------------------------ #
-        # Canonical ID helpers                                               #
-        # ------------------------------------------------------------------ #
-
+    # ------------------------------------------------------------------ #
+    # Canonical ID helpers                                               #
+    # ------------------------------------------------------------------ #
     def _compute_iou(self, box1: Any, box2: Any) -> float:
         """Compute IoU between two bounding boxes which may be dicts or lists.
         Falls back to 0 when insufficient data is available."""
@@ -560,6 +719,9 @@ class ChildMonitoringUseCase(BaseProcessor):
         return (inter_area / union_area) if union_area > 0 else 0.0
 
     def _merge_or_register_track(self, raw_id: Any, bbox: Any) -> Any:
+        """Return a stable canonical ID for a raw tracker ID, merging fragmented
+        tracks when IoU and temporal constraints indicate they represent the
+        same physical."""
         if raw_id is None or bbox is None:
             # Nothing to merge
             return raw_id
@@ -612,4 +774,4 @@ class ChildMonitoringUseCase(BaseProcessor):
 
     def _set_tracking_start_time(self) -> None:
         """Set the tracking start time to the current time."""
-        self._tracking_start_time = time.time()
\ No newline at end of file
+        self._tracking_start_time = time.time()
